OpenSubmarine | Contracts

A library for secure smart contract development. Build on a solid foundation of community-vetted code similar to OpenZeppelin but for the Algorand Virtual Machine (AVM) and using Algorand Python instead of Solidity. Testing is done using Algorand Pythnon Testing and Mocha and Chai frameworks.

* Implementations of token standards like ARC200 and ARC72.
* Flexible role-based permissioning scheme.
* Reusable Algorand python components to build custom contracts and complex decentralized systems.

## Contributing
Please see our [Contributing Guide](CONTRIBUTING.md) for instructions on how to set up the development environment and submit changes.

## Publishing
For maintainers: See the [Contributing Guide](CONTRIBUTING.md#publishing-to-pypi) for instructions on publishing new versions to PyPI.